EMIZ
----

Etcher's Mission File Tools

|OSI|

|license|

|av_master| |av_develop|


.. |OSI| image:: https://badges.frapsoft.com/os/v3/open-source-200x33.png?v=103
    :target: https://github.com/ellerbrock/open-source-badges/
.. |license| image:: https://img.shields.io/github/license/132nd-etcher/EMIZ.svg
    :target: https://www.gnu.org/licenses/gpl-3.0.en.html
.. |av_master| image:: https://img.shields.io/appveyor/ci/132nd-etcher/emiz/master.svg?label=master
    :target: https://ci.appveyor.com/project/132nd-etcher/emiz
.. |av_develop| image:: https://img.shields.io/appveyor/ci/132nd-etcher/emiz/develop.svg?label=develop
    :target: https://ci.appveyor.com/project/132nd-etcher/emiz